@@ -3,7 +3,7 @@ mps2cps<-function(mps) {
   if(is.list(mps)==FALSE) {
     stop('mps must be a list.')
   }
-  if(all(unlist(lapply(mps, sum))==1)!=TRUE) {
+  if(any(unlist(lapply(mps, sum))>(1+.Machine$double.eps^0.5)) | any(unlist(lapply(mps, sum))<(1-.Machine$double.eps^0.5))) { #tolerance added for use across platforms
     stop('Marginal probabilities in each respective element of the given list must sum to 1.')
   }
   if(min(unlist(lapply(mps, min)))<0 | max(unlist(lapply(mps, min)))>1) {
